netapp_ontap.models.volume_efficiency_scanner API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.volume_efficiency_scanner`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VolumeEfficiencyScannerSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VolumeEfficiencyScanner object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `compression: bool GET PATCH`

    Start compression if scanning old data. Valid for PATCH and GET. This option is not supported for FSX/CVO platforms.

  `dedupe: bool GET PATCH`

    Start deduplication if scanning old data. Valid for PATCH and GET.

  `scan_old_data: bool GET PATCH`

    Indicates whether or not to scan old data. Valid for PATCH and GET.

  `state: str GET PATCH`

    State of the volume efficiency scanner. Valid for PATCH and GET. Valid options for PATCH are "idle" and "active".

    Valid choices:

    - idle
    - initializing
    - active
    - undoing
    - pending
    - downgrading
    - disabled